/*
	The MIT License
	
	Copyright (c) 2008-2009 Mark Walters
	
	Permission is hereby granted, free of charge, to any person obtaining a copy
	of this software and associated documentation files (the "Software"), to deal
	in the Software without restriction, including without limitation the rights
	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
	copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:
	
	The above copyright notice and this permission notice shall be included in
	all copies or substantial portions of the Software.
	
	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
	OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
	THE SOFTWARE.
*/

package com.yourpalmark.geoglobe
{
	import org.papervision3d.events.InteractiveScene3DEvent;
	import org.papervision3d.materials.ColorMaterial;
	import org.papervision3d.materials.utils.MaterialsList;
	import org.papervision3d.objects.DisplayObject3D;
	import org.papervision3d.objects.primitives.Cube;
	
	public class Marker extends DisplayObject3D
	{
		private var cube:Cube;
		
		private var _width:Number = 12;
		private var _height:Number = 12;
		private var _depth:Number = 34;
		
		public function Marker()
		{
			super();
			
			var frontMaterial:ColorMaterial = new ColorMaterial( 0xff7200, 1, true );
			var backMaterial:ColorMaterial = new ColorMaterial( 0xff7200, 1, true );
			var leftMaterial:ColorMaterial = new ColorMaterial( 0xff6100, 1, true );
			var rightMaterial:ColorMaterial = new ColorMaterial( 0xff6100, 1, true );
			var topMaterial:ColorMaterial = new ColorMaterial( 0xff4f00, 1, true );
			var bottomMaterial:ColorMaterial = new ColorMaterial( 0xff4f00, 1, true );
			
			var materials:MaterialsList = new MaterialsList( { front:frontMaterial, back:backMaterial, left:leftMaterial, right:rightMaterial, top:topMaterial, bottom:bottomMaterial } );
			cube = new Cube( materials, width, depth, height );
			cube.addEventListener( InteractiveScene3DEvent.OBJECT_OVER, onCubeOver, false, 0, true );
			cube.addEventListener( InteractiveScene3DEvent.OBJECT_OUT, onCubeOut, false, 0, true );
			cube.addEventListener( InteractiveScene3DEvent.OBJECT_CLICK, onCubeClick, false, 0, true );
			cube.geometry.vertices[0].x -= 4;
			cube.geometry.vertices[0].y += 4;
			cube.geometry.vertices[1].x -= 4;
			cube.geometry.vertices[1].y -= 4;
			cube.geometry.vertices[2].x += 4;
			cube.geometry.vertices[2].y += 4;
			cube.geometry.vertices[3].x += 4;
			cube.geometry.vertices[3].y -= 4;
			addChild( cube );
			cube.moveBackward( depth / 2 );
		}
		
		public function get width():Number { return _width; }
		
		public function get height():Number { return _height; }
		
		public function get depth():Number { return _depth; }
		
		
		private function onCubeOver( event:InteractiveScene3DEvent ):void
		{
			var clonedEvent:InteractiveScene3DEvent = new InteractiveScene3DEvent( event.type, event.displayObject3D, event.sprite, event.face3d, event.x, event.y, event.renderHitData, event.bubbles, event.cancelable );
			dispatchEvent( clonedEvent );
		}
		
		private function onCubeOut( event:InteractiveScene3DEvent ):void
		{
			var clonedEvent:InteractiveScene3DEvent = new InteractiveScene3DEvent( event.type, event.displayObject3D, event.sprite, event.face3d, event.x, event.y, event.renderHitData, event.bubbles, event.cancelable );
			dispatchEvent( clonedEvent );
		}
		
		private function onCubeClick( event:InteractiveScene3DEvent ):void
		{
			var clonedEvent:InteractiveScene3DEvent = new InteractiveScene3DEvent( event.type, event.displayObject3D, event.sprite, event.face3d, event.x, event.y, event.renderHitData, event.bubbles, event.cancelable );
			dispatchEvent( clonedEvent );
		}
		
	}
}